==> smartgwt-6.1p.zip: com/smartgwt/logicalstructure/widgets/cube/CubeGridLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.cube;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class CubeGridLogicalStructure extends ListGridLogicalStructure {
    public String alternateRecordStyles;
    public String autoFetchTextMatchStyle;
    public String autoSelectHeaders;
    public String autoSelectValues;
    public String autoSizeHeaders;
    public String baseStyle;
    public String bodyMinHeight;
    public String bodyMinWidth;
    public String bodyStyleName;
    public String canCollapseFacets;
    public String canDragSelect;
    public String canEdit;
    public String canMinimizeColumns;
    public String canMinimizeFacets;
    public String canMoveFacets;
    public String canReorderColumns;
    public String canResizeColumns;
    public String canSelectHeaders;
    public String canSelectValues;
    public String canSortData;
    public String canSortFacets;
    public String cellAlign;
    public String cellIdProperty;
    public String chartConfirmThreshold;
    public String chartConstructor;
    public String chartType;
    public String colHeaderBaseStyle;
    public String[] columnFacets;
    public CellRecord[] data;
    public DataSource dataSource;
    public String defaultFacetWidth;
    public String editByCell;
    public String enableCharting;
    public String exportColumnFacetBGColor;
    public String exportColumnFacetTextColor;
    public String exportFacetBGColor;
    public String exportFacetSeparatorString;
    public String exportFacetTextColor;
    public String exportRowFacetBGColor;
    public String exportRowFacetTextColor;
    public String facetLabelHoverAlign;
    public String facetLabelHoverHeight;
    public String facetLabelHoverStyle;
    public String facetLabelHoverVAlign;
    public String facetLabelHoverWidth;
    public String facetTitleAlign;
    public String facetValueAlign;
    public MenuItem[] facetValueContextItems;
    public String facetValueHoverAlign;
    public String facetValueHoverHeight;
    public String facetValueHoverStyle;
    public String facetValueHoverVAlign;
    public String facetValueHoverWidth;
    public FacetValueMap fixedFacetValues;
    public String hideEmptyAxis;
    public String hideEmptyFacetValues;
    public Hilite[] hilites;
    public String innerHeaderBaseStyle;
    public String metricFacetId;
    public String padTitles;
    public String rollupValue;
    public String[] rowFacets;
    public String rowHeaderBaseStyle;
    public String rowHeaderGridMode;
    public String saveByCell;
    public String showFacetContextMenus;
    public String showFacetValueContextMenus;
    public String simpleDeselect;
    public String skinImgDir;
    public String sortDirection;
    public FacetValueMap sortedFacetValues;
    public String styleName;
    public String valueExportFormat;
    public String valueFormat;
    public String valueProperty;
    public String valueTitle;
    public String wrapFacetTitles;
    public String wrapFacetValueTitles;
}

==> smartgwt-12.1p.zip: com/smartgwt/logicalstructure/widgets/cube/CubeGridLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.cube;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class CubeGridLogicalStructure extends ListGridLogicalStructure {
    public String alternateRecordStyles;
    public String autoFetchTextMatchStyle;
    public String autoFitFieldWidths;
    public String autoSelectHeaders;
    public String autoSelectValues;
    public String autoSizeHeaders;
    public String baseStyle;
    public String bodyMinHeight;
    public String bodyMinWidth;
    public String bodyStyleName;
    public String canCollapseFacets;
    public String canDragSelect;
    public String canEdit;
    public String canMinimizeColumns;
    public String canMinimizeFacets;
    public String canMoveFacets;
    public String canReorderColumns;
    public String canResizeColumns;
    public String canSelectHeaders;
    public String canSelectValues;
    public String canSortData;
    public String canSortFacets;
    public String cellAlign;
    public String cellIdProperty;
    public String chartConfirmThreshold;
    public String chartConstructor;
    public String chartType;
    public String colHeaderBaseStyle;
    public String colHeaderLabelBaseStyle;
    public String[] columnFacets;
    public CellRecord[] data;
    public DataSource dataSource;
    public String defaultFacetWidth;
    public String editByCell;
    public String enableCharting;
    public String exportColumnFacetBGColor;
    public String exportColumnFacetTextColor;
    public String exportFacetBGColor;
    public String exportFacetSeparatorString;
    public String exportFacetTextColor;
    public String exportRowFacetBGColor;
    public String exportRowFacetTextColor;
    public String facetLabelHoverAlign;
    public String facetLabelHoverHeightAsString;
    public String facetLabelHoverStyle;
    public String facetLabelHoverVAlign;
    public String facetLabelHoverWidthAsString;
    public String facetTitleAlign;
    public String facetValueAlign;
    public MenuItem[] facetValueContextItems;
    public String facetValueHoverAlign;
    public String facetValueHoverHeightAsString;
    public String facetValueHoverStyle;
    public String facetValueHoverVAlign;
    public String facetValueHoverWidthAsString;
    public FacetValueMap fixedFacetValues;
    public String hideEmptyAxis;
    public String hideEmptyFacetValues;
    public Hilite[] hilites;
    public String indentVTreeFacets;
    public String innerHeaderBaseStyle;
    public String metricFacetId;
    public String padTitles;
    public String rollupValue;
    public String rotateHeaderTitles;
    public String[] rowFacets;
    public String rowHeaderBaseStyle;
    public String rowHeaderGridMode;
    public String rowHeaderLabelBaseStyle;
    public String saveByCell;
    public String showFacetContextMenus;
    public String showFacetValueContextMenus;
    public String simpleDeselect;
    public String skinImgDir;
    public String sortDirection;
    public FacetValueMap sortedFacetValues;
    public String styleName;
    public String valueExportFormat;
    public String valueFormat;
    public String valueProperty;
    public String valueTitle;
    public String vTreeFacetIndent;
    public String vTreeFacetIndentDirection;
    public String wrapFacetTitles;
    public String wrapFacetValueTitles;
}
